from zaiclient.request.Events.AddPageViewEvent import AddPageViewEvent
from zaiclient.request.Events.AddProductDetailViewEvent import AddProductDetailViewEvent
from zaiclient.request.Events.AddSearchEvent import AddSearchEvent
from zaiclient.request.Events.AddLikeEvent import AddLikeEvent
from zaiclient.request.Events.AddCartaddEvent import AddCartaddEvent
from zaiclient.request.Events.AddPurchaseEvent import AddPurchaseEvent
from zaiclient.request.Events.AddRateEvent import AddRateEvent
from zaiclient.request.Events.AddCustomEvent import AddCustomEvent
from zaiclient.request.Events.EventRequest import EventRequest
from zaiclient.request.Events.Event import Event
from zaiclient.request.Recommendations.GetUserRecommendation import GetUserRecommendation
from zaiclient.request.Recommendations.GetRelatedItemsRecommendation import GetRelatedItemsRecommendation
from zaiclient.request.Recommendations.GetRerankingRecommendation import GetRerankingRecommendation
from zaiclient.request.Recommendations.Recommendation import Recommendation
from zaiclient.request.Recommendations.RecommendationRequest import RecommendationRequest
from zaiclient.request.Items.AddItem import AddItem
from zaiclient.request.Items.DeleteItem import DeleteItem
from zaiclient.request.Items.UpdateItem import UpdateItem
from zaiclient.request.Items.Item import Item
from zaiclient.request.Items.ItemRequest import ItemRequest
from zaiclient.request.Request import Request