# HTTPS
COLLECTOR_API_ENDPOINT = "https://collector-api{}.zaikorea.org"
EVENTS_API_PATH = "/events"
ITEMS_API_PATH = "/items"

ML_API_ENDPOINT = "https://ml-api{}.zaikorea.org"
ML_API_PATH_PREFIX = "/clients/{}/recommenders"
USER_RECOMMENDATION_PATH_PREFIX = "/user-recommendations"
RELATED_ITEMS_RECOMMENDATION_PATH_PREFIX = "/related-items"
RERANKING_RECOMMENDATION_PATH_PREFIX = "/reranking"


HMAC_ALGORITHM = "HmacSHA256"
HMAC_SCHEME = "ZAi"

# HTTP Custom Headers
ZAI_CLIENT_ID_HEADER = "X-ZAI-CLIENT-ID"
ZAI_UNIX_TIMESTAMP_HEADER = "X-ZAI-TIMESTAMP"
ZAI_AUTHORIZATION_HEADER = "X-ZAI-AUTHORIZATION"

BATCH_REQUEST_CAP = 50
EPSILON = 1e-4
CONNECT_TIMEOUT_S = 10
READ_TIMEOUT_S = 30

TEST_EVENT_TIME_TO_LIVE = 60 * 60 * 24 # 1 day